﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub AT DSO/DSA90254A (1 yr) Bandwidth VER VISA /9530
DATE:                  2011-02-18 09:30:29
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       9
NUMBER OF LINES:       295
CONFIGURATION:         Datron 9500 (G3)
CONFIGURATION:         Datron 9530 on channel 1
=============================================================================
#
#  Procedure Author:
#        DFM, CAD
#
#  Model(s) Covered:
#        Agilent DSO/DSA90254A Infiniium Oscilloscope
#
#  Compatibility:
#        MET/CAL 7.3 or later
#
#  Subprocedures:
#        Sub Agilent Infiniium Channel Selection VISA
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  CALL         Sub Agilent Infiniium Channel Selection VISA

  # Establish Device Name and Mode String for accuracy file lookup.
  1.002  MATH         Dev  = INSTR("9500")
  1.003  MATH         Mode = "Vpp LS G3 L"

# Define Analog Bandwidth maximum test frequency.
  1.004  MATH         MaxFreq = @Bandwidth / 1E+9

  1.005  IF           @Chan == 1
  1.006  RSLT         =
  1.007  HEAD         {ANALOG BANDWIDTH - MAXIMUM FREQUENCY CHECK}
  1.008  RSLT         =(Response at [V MaxFreq] GHz, dB)
  1.009  ELSE
  1.010  HEAD         ANALOG BANDWIDTH - MAXIMUM FREQUENCY CHECK
  1.011  ENDIF

  1.012  RSLT         =
  1.013  HEAD         -2 {Channel [V @Chan]}: 5 mV/div
  1.014  TARGET       -p
  1.015  VISA         CHAN[V @Chan]:SCAL 5E-3;OFFS 0V
  1.016  VISA         ACQ:POIN AUTO;SRAT MAX;INT ON;AVER OFF
  1.017  VISA         TRIG:EDGE:SLOP POS;SOUR CHAN[V @Chan]
  1.018  TSET         TDESC = 5 mV/div
  1.019  TARGET       -m
  1.020  VISA         TIMEBASE:SCALE 16E-9
  1.021  MATH         MEM = 20E-3; MEM1 = MEM

# Set the output of the calibrator so the peak-to-peak measurement is
# between 19.9 and 20.1 mVpp (4 divisions).
  1.022  DO
  1.023  MATH         MEM = MEM1 + (20E-3 - MEM) / 2
  1.024  9500         Vpp                          50MH           LS    S  L
  1.025  WAIT         [D1000]
  1.026  VISA         MEAS:VPP? CHAN[V @Chan][I]
  1.027  UNTIL        (MEM >= 19.9E-3) && (MEM <= 20.1E-3) || (MEM >= 40E-3)

# Store UUT amplitude reading (Vrms) at reference frequency.
  1.028  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  1.029  MATH         RefAmpl = MEM

  1.030  VISA         TIMEBASE:SCALE 100E-12

# Copy last calibrator amplitude setting (in MEM1) to MEM to set 9500 output.
  1.031  MATH         MEM = MEM1
  1.032  9500         Vpp                          2.5GH          LS    S  L
  1.033  WAIT         [D2000]

# 9530 Active Head flatness error expressed in dB.
  1.034  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  1.035  MATH         Percent = (Acc / MEM) * 100
  1.036  MATH         L[1] = PCTTODBV_D(Percent)
  1.037  ACC          0.00dB         L1U

  1.038  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
# Compute 'dB down' from reference at UUT rated bandwidth.
  1.039  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  1.040  MEMCX        0.00dB         3.00U

  2.001  HEAD         -2 Channel [V @Chan]: 10 mV/div
  2.002  TARGET       -p
  2.003  VISA         CHAN[V @Chan]:SCAL 10E-3
  2.004  TSET         TDESC = 10 mV/div
  2.005  TARGET       -m
  2.006  VISA         TIMEBASE:SCALE 16E-9
  2.007  MATH         MEM = 40E-3; MEM1 = MEM

  2.008  DO
  2.009  MATH         MEM = MEM1 + (40E-3 - MEM) / 2
  2.010  9500         Vpp                          50MH           LS    S  L
  2.011  WAIT         [D1000]
  2.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  2.013  UNTIL        (MEM >= 39.8E-3) && (MEM <= 40.2E-3) || (MEM >= 80E-3)

  2.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  2.015  MATH         RefAmpl = MEM; MEM = MEM1
  2.016  VISA         TIMEBASE:SCALE 100E-12
  2.017  9500         Vpp                          2.5GH          LS    S  L

  2.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  2.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  2.020  ACC          0.00dB         L1U

  2.021  WAIT         [D2000]
  2.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  2.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  2.024  MEMCX        0.00dB         3.00U

  3.001  HEAD         -2 Channel [V @Chan]: 20 mV/div
  3.002  TARGET       -p
  3.003  VISA         CHAN[V @Chan]:SCAL 20E-3
  3.004  TSET         TDESC = 20 mV/div
  3.005  TARGET       -m
  3.006  VISA         TIMEBASE:SCALE 16E-9
  3.007  MATH         MEM = 80E-3; MEM1 = MEM

  3.008  DO
  3.009  MATH         MEM = MEM1 + (80E-3 - MEM) / 2
  3.010  9500         Vpp                          50MH           LS    S  L
  3.011  WAIT         [D1000]
  3.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  3.013  UNTIL        (MEM >= 79.6E-3) && (MEM <= 80.4E-3) || (MEM > 160E-3)

  3.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  3.015  MATH         RefAmpl = MEM; MEM = MEM1
  3.016  VISA         TIMEBASE:SCALE 100E-12
  3.017  9500         Vpp                          2.5GH          LS    S  L
  3.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  3.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  3.020  ACC          0.00dB         L1U
  3.021  WAIT         [D2000]
  3.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  3.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  3.024  MEMCX        0.00dB         3.00U

  4.001  HEAD         -2 Channel [V @Chan]: 50 mV/div
  4.002  TARGET       -p
  4.003  VISA         CHAN[V @Chan]:SCAL 50E-3
  4.004  TSET         TDESC = 50 mV/div
  4.005  TARGET       -m
  4.006  VISA         TIMEBASE:SCALE 16E-9
  4.007  MATH         MEM = 200E-3; MEM1 = MEM

  4.008  DO
  4.009  MATH         MEM = MEM1 + (200E-3 - MEM) / 2
  4.010  9500         Vpp                          50MH           LS    S  L
  4.011  WAIT         [D1000]
  4.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  4.013  UNTIL        (MEM >= 199E-3) && (MEM <= 201E-3) || (MEM >= 400E-3)

  4.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  4.015  MATH         RefAmpl = MEM; MEM = MEM1
  4.016  VISA         TIMEBASE:SCALE 100E-12
  4.017  9500         Vpp                          2.5GH          LS    S  L
  4.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  4.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  4.020  ACC          0.00dB         L1U
  4.021  WAIT         [D2000]
  4.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  4.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  4.024  MEMCX        0.00dB         3.00U

  5.001  HEAD         -2 Channel [V @Chan]: 100 mV/div
  5.002  TARGET       -p
  5.003  VISA         CHAN[V @Chan]:SCAL 100E-3
  5.004  TSET         TDESC = 100 mV/div
  5.005  TARGET       -m
  5.006  VISA         TIMEBASE:SCALE 16E-9
  5.007  MATH         MEM = 400E-3; MEM1 = MEM

  5.008  DO
  5.009  MATH         MEM = MEM1 + (400E-3 - MEM) / 2
  5.010  9500         Vpp                          50MH           LS    S  L
  5.011  WAIT         [D1000]
  5.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  5.013  UNTIL        (MEM >= 398E-3) && (MEM <= 402E-3) || (MEM >= 800E-3)

  5.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  5.015  MATH         RefAmpl = MEM; MEM = MEM1
  5.016  VISA         TIMEBASE:SCALE 100E-12
  5.017  9500         Vpp                          2.5GH          LS    S  L
  5.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  5.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  5.020  ACC          0.00dB         L1U
  5.021  WAIT         [D2000]
  5.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  5.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  5.024  MEMCX        0.00dB         3.00U

  6.001  HEAD         -2 Channel [V @Chan]: 200 mV/div
  6.002  TARGET       -p
  6.003  VISA         CHAN[V @Chan]:SCAL 200E-3
  6.004  TSET         TDESC = 200 mV/div
  6.005  TARGET       -m
  6.006  VISA         TIMEBASE:SCALE 16E-9
  6.007  MATH         MEM = 800E-3; MEM1 = MEM

  6.008  DO
  6.009  MATH         MEM = MEM1 + (800E-3 - MEM) / 2
  6.010  9500         Vpp                          50MH           LS    S  L
  6.011  WAIT         [D1000]
  6.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  6.013  UNTIL        (MEM >= 796E-3) && (MEM <= 804E-3) || (MEM >= 1.6)

  6.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  6.015  MATH         RefAmpl = MEM; MEM = MEM1
  6.016  VISA         TIMEBASE:SCALE 100E-12
  6.017  9500         Vpp                          2.5GH          LS    S  L
  6.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  6.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  6.020  ACC          0.00dB         L1U
  6.021  WAIT         [D2000]
  6.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  6.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  6.024  MEMCX        0.00dB         3.00U

  7.001  HEAD         -2 Channel [V @Chan]: 500 mV/div
  7.002  TARGET       -p
  7.003  VISA         CHAN[V @Chan]:SCAL 500E-3
  7.004  TSET         TDESC = 500 mV/div
  7.005  TARGET       -m
  7.006  VISA         TIMEBASE:SCALE 16E-9
  7.007  MATH         MEM = 2; MEM1 = MEM

  7.008  DO
  7.009  MATH         MEM = MEM1 + (2 - MEM) / 2
  7.010  9500         Vpp                          50MH           LS    S  L
  7.011  WAIT         [D1000]
  7.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  7.013  UNTIL        (MEM >= 1.99) && (MEM <= 2.01) || (MEM >= 4)

  7.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  7.015  MATH         RefAmpl = MEM; MEM = MEM1
  7.016  VISA         TIMEBASE:SCALE 100E-12
  7.017  9500         Vpp                          2.5GH          LS    S  L
  7.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  7.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  7.020  ACC          0.00dB         L1U
  7.021  WAIT         [D2000]
  7.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  7.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  7.024  MEMCX        0.00dB         3.00U

  8.001  HEAD         -2 Channel [V @Chan]: 1 V/div
  8.002  TARGET       -p
  8.003  VISA         CHAN[V @Chan]:SCAL 1
  8.004  TSET         TDESC = 1 V/div
  8.005  TARGET       -m
  8.006  VISA         TIMEBASE:SCALE 16E-9
# Due to 9530 head amplitude limitations, a 2 division reference is used.
  8.007  MATH         MEM = 2; MEM1 = MEM

  8.008  DO
  8.009  MATH         MEM = MEM1 + (2 - MEM) / 2
  8.010  9500         Vpp                          50MH           LS    S  L
  8.011  WAIT         [D1000]
  8.012  VISA         MEAS:VPP? CHAN[V @Chan][I]
  8.013  UNTIL        (MEM >= 1.99) && (MEM <= 2.01) || (MEM >= 5)

  8.014  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  8.015  MATH         RefAmpl = MEM; MEM = MEM1
  8.016  VISA         TIMEBASE:SCALE 100E-12
  8.017  9500         Vpp                          2.5GH          LS    S  L
  8.018  MATH         Acc = ACCV2(Dev, Mode, MEM, 2.5E+9)
  8.019  MATH         L[1] = PCTTODBV_D((Acc / MEM) * 100)
  8.020  ACC          0.00dB         L1U
  8.021  WAIT         [D2000]
  8.022  VISA         MEAS:VRMS? DISP,AC,CHAN[V @Chan][I]
  8.023  MATH         MEM = (20 * LOG(MEM / RefAmpl))
  8.024  MEMCX        0.00dB         3.00U

  9.001  9500         *                                                 S
  9.002  VISA         *RST
  9.003  HEAD
  9.004  HEAD         -2
  9.005  END
